==> emodpy_covid-0.0.30-py3-none-any.whl: emodpy_covid/microstructure/test_spops_interface.py <==
import json
import unittest
import os
import hashlib

# Module under test
from emod_api.serialization import SerializedPopulation as SP

class SerializedPopulationInterfaceTest(unittest.TestCase):
    def setUp(self) -> None:
        my_path = os.getcwd()
        self.generic_spop_path = os.path.join(my_path, "TestContent", "state-generic-00050.dtk")
        self.environmental_spop_path = os.path.join(my_path, "TestContent", "state-environmental-00050.dtk")
        if not os.path.isfile(self.generic_spop_path):
            raise FileNotFoundError(f"Need {self.generic_spop_path} in place to run these tests")
        if not os.path.isfile(self.environmental_spop_path):
            raise FileNotFoundError(f"Need {self.environmental_spop_path} in place to run these tests")
        self.written_file_path = None 

    def tearDown(self) -> None:
        if self.written_file_path:
            os.unlink(self.written_file_path)

    def get_md5(self, filepath):
        local_hash = hashlib.md5()
        file_object = open(filepath, "rb")
        file_bytes = file_object.read()
        local_hash.update(file_bytes)
        file_object.close()
        return local_hash

    def get_gen_pop(self):
        return SP.SerializedPopulation(self.generic_spop_path)

    def get_env_pop(self):
        return SP.SerializedPopulation(self.environmental_spop_path)

    def test_prereq_two_files_different(self):
        gen_state_hash = self.get_md5(self.generic_spop_path)
        env_state_hash = self.get_md5(self.environmental_spop_path)
        self.assertNotEqual(gen_state_hash, env_state_hash,
                            msg="If these are the same, something is super broken.")
        

    def test_read_file_get_right_node_count(self):
        gen_pop = self.get_gen_pop()
        self.assertEqual(len(gen_pop._nodes), 1)

        env_pop = self.get_env_pop()
        self.assertEqual(len(env_pop._nodes), 1)

    @unittest.skip("Seems to fail. Maybe it is the next infection suid")
    def test_write_no_changes_same_file(self):
        gen_pop = self.get_gen_pop()
        gen_pop.write()
        default_filepath = "my_sp_file.dtk"
        self.assertTrue(os.path.isfile(default_filepath))
        self.written_file_path = default_filepath
        my_md5 = self.get_md5(default_filepath)
        start_md5 = self.get_md5(self.generic_spop_path)
        self.assertEqual(my_md5.digest(), start_md5.digest(),
                         msg=f"New File {default_filepath} should have"
                             f" same md5 as {self.generic_spop_path}")
        

    @unittest.skip("NYI")
    def test_write_less_individuals_smaller(self):
        gen_pop = self.get_gen_pop()
        # TODO: remove 100 people
        # TODO: write file, set self.written_file_path
        # TODO: compare file sizes
        

    @unittest.skip("NYI")
    def test_add_infections_across(self):
        # TODO: load target file and get an infection
        # TODO: add infection to every person
        # TODO: make sure each person has an infection
        pass

if __name__ == '__main__':
    unittest.main()

==> emodpy_covid-0.0.32-py3-none-any.whl: emodpy_covid/microstructure/test_spops_interface.py <==
import json
import unittest
import os
import hashlib

# Module under test
import emod_api.serialization.SerializedPopulation as SP

class SerializedPopulationInterfaceTest(unittest.TestCase):
    def setUp(self) -> None:
        my_path = os.getcwd()
        self.generic_spop_path = os.path.join(my_path, "TestContent", "state-generic-00050.dtk")
        self.environmental_spop_path = os.path.join(my_path, "TestContent", "state-environmental-00050.dtk")
        if not os.path.isfile(self.generic_spop_path):
            raise FileNotFoundError(f"Need {self.generic_spop_path} in place to run these tests")
        if not os.path.isfile(self.environmental_spop_path):
            raise FileNotFoundError(f"Need {self.environmental_spop_path} in place to run these tests")
        self.written_file_path = None 

    def tearDown(self) -> None:
        if self.written_file_path:
            # os.unlink(self.written_file_path)

    def get_md5(self, filepath):
        local_hash = hashlib.md5()
        file_object = open(filepath, "rb")
        file_bytes = file_object.read()
        local_hash.update(file_bytes)
        file_object.close()
        return local_hash

    def get_gen_pop(self):
        return SP.SerializedPopulation(self.generic_spop_path)

    def get_env_pop(self):
        return SP.SerializedPopulation(self.environmental_spop_path)

    def test_prereq_two_files_different(self):
        gen_state_hash = self.get_md5(self.generic_spop_path)
        env_state_hash = self.get_md5(self.environmental_spop_path)
        self.assertNotEqual(gen_state_hash, env_state_hash,
                            msg="If these are the same, something is super broken.")
        

    def test_read_file_get_right_node_count(self):
        gen_pop = self.get_gen_pop()
        self.assertEqual(len(gen_pop._nodes), 1)

        env_pop = self.get_env_pop()
        self.assertEqual(len(env_pop._nodes), 1)

    @unittest.skip("Seems to fail. Maybe it is the next infection suid")
    def test_write_no_changes_same_file(self):
        gen_pop = self.get_gen_pop()
        gen_pop.write()
        default_filepath = "my_sp_file.dtk"
        self.assertTrue(os.path.isfile(default_filepath))
        self.written_file_path = default_filepath
        my_md5 = self.get_md5(default_filepath)
        start_md5 = self.get_md5(self.generic_spop_path)
        self.assertEqual(my_md5.digest(), start_md5.digest(),
                         msg=f"New File {default_filepath} should have"
                             f" same md5 as {self.generic_spop_path}")
        

    @unittest.skip("NYI")
    def test_write_less_individuals_smaller(self):
        gen_pop = self.get_gen_pop()
        # TODO: remove 100 people
        # TODO: write file, set self.written_file_path
        # TODO: compare file sizes
        

    @unittest.skip("NYI")
    def test_add_infections_across(self):
        # TODO: load target file and get an infection
        # TODO: add infection to every person
        # TODO: make sure each person has an infection
